/*
 * Calculate Android Copyright <C> 2020 - 2025 Jonas Lochmann
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation version 3 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see https://www.gnu.org/licenses/
 */
package com.rechnen.app.ui

import android.os.Bundle
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.verticalScroll
import androidx.compose.material3.Card
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.material3.TopAppBar
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.unit.dp
import androidx.fragment.app.FragmentActivity
import com.rechnen.app.BuildConfig
import com.rechnen.app.R
import com.rechnen.app.ui.view.HyperlinkText

class AboutActivity : FragmentActivity() {
    @OptIn(ExperimentalMaterial3Api::class)
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        enableEdgeToEdge()

        setContent {
            AppTheme {
                Scaffold(
                    topBar = {
                        TopAppBar(title = {
                            Text(stringResource(R.string.about_title))
                        })
                    },
                    content = { paddingValues ->
                        Column(
                            Modifier
                                .verticalScroll(rememberScrollState())
                                .padding(paddingValues)
                                .padding(8.dp),
                            verticalArrangement = Arrangement.spacedBy(8.dp)
                        ) {
                            Card {
                                Column(
                                    Modifier.fillMaxWidth().padding(8.dp),
                                    verticalArrangement = Arrangement.spacedBy(8.dp)
                                ) {
                                    Text(
                                        stringResource(R.string.app_name),
                                        style = MaterialTheme.typography.titleMedium
                                    )
                                    Text(
                                        stringResource(
                                            R.string.about_version,
                                            BuildConfig.VERSION_NAME
                                        )
                                    )
                                }
                            }

                            Card {
                                Column(
                                    Modifier.fillMaxWidth().padding(8.dp),
                                    verticalArrangement = Arrangement.spacedBy(8.dp)
                                ) {
                                    Text(
                                        stringResource(R.string.about_license_title),
                                        style = MaterialTheme.typography.titleMedium
                                    )
                                    HyperlinkText(getText(R.string.about_license_text))
                                }
                            }

                            Card {
                                Column(
                                    Modifier.fillMaxWidth().padding(8.dp),
                                    verticalArrangement = Arrangement.spacedBy(8.dp)
                                ) {
                                    Text(
                                        stringResource(R.string.about_developer_key_title),
                                        style = MaterialTheme.typography.titleMedium
                                    )
                                    Text(stringResource(R.string.about_developer_key_text))
                                }
                            }

                            Card {
                                Column(
                                    Modifier.fillMaxWidth().padding(8.dp),
                                    verticalArrangement = Arrangement.spacedBy(8.dp)
                                ) {
                                    Text(
                                        stringResource(R.string.about_source_title),
                                        style = MaterialTheme.typography.titleMedium
                                    )
                                    HyperlinkText(getText(R.string.about_source_text))
                                }
                            }
                        }
                    }
                )
            }
        }
    }
}
