/*
 * Calculate Android Copyright <C> 2020 - 2025 Jonas Lochmann
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation version 3 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see https://www.gnu.org/licenses/
 */
package com.rechnen.app.ui.user

import android.content.Context
import android.content.Intent
import android.os.Bundle
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Button
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.ModalBottomSheet
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Slider
import androidx.compose.material3.Text
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.saveable.rememberSaveable
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.stringResource
import androidx.fragment.app.FragmentActivity
import com.rechnen.app.R
import com.rechnen.app.data.modelparts.InputConfiguration
import com.rechnen.app.extension.useJsonReader
import com.rechnen.app.extension.writeJson
import com.rechnen.app.ui.AppTheme
import com.rechnen.app.ui.training.ConfirmButton
import com.rechnen.app.ui.training.Listener
import com.rechnen.app.ui.training.TaskViewLine
import com.rechnen.app.ui.training.TaskViewLines
import com.rechnen.app.ui.training.TrainingMainActivity
import kotlin.math.roundToInt

class ConfigureScaleFactorActivity: FragmentActivity() {
    companion object {
        const val EXTRA_INITIAL_CONFIG = "config"
        const val RESULT_EXTRA_FACTOR = "factor"

        fun buildIntent(context: Context, inputConfiguration: InputConfiguration) = Intent(context, ConfigureScaleFactorActivity::class.java)
                .putExtra(EXTRA_INITIAL_CONFIG, writeJson { inputConfiguration.serialize(it) })
    }

    @OptIn(ExperimentalMaterial3Api::class)
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        val initialConfig = intent.getStringExtra(EXTRA_INITIAL_CONFIG)!!.useJsonReader { InputConfiguration.parse(it) }

        enableEdgeToEdge()

        setContent {
            var size by rememberSaveable { mutableStateOf(initialConfig.size) }

            AppTheme {
                Scaffold { insets ->
                    TrainingMainActivity.TrainingScreen(
                        progress = { 0.5f },
                        lines = TaskViewLines(listOf(
                            TaskViewLine("", "123"),
                            TaskViewLine("+", "456"),
                            TaskViewLine("=", "579")
                        )),
                        keyboardConfiguration = initialConfig.copy(size = size),
                        keyboardConfirmButton = ConfirmButton.Regular,
                        keyboardEnabled = false,
                        keyboardListener = object: Listener {
                            override fun onConfirmClicked() {/* ignore */}
                            override fun onDeleteClicked() {/* ignore */}
                            override fun onDigitEntered(digit: Int) {/* ignore */}
                        },
                        modifier = Modifier.padding(insets)
                    )

                    ModalBottomSheet(
                        onDismissRequest = { finish() },
                        content = {
                            Slider(
                                value = size.toFloat(),
                                onValueChange = { size = it.roundToInt() },
                                steps = 9,
                                valueRange = 0f..100f
                            )

                            Button(
                                onClick = {
                                    setResult(RESULT_OK, Intent().putExtra(RESULT_EXTRA_FACTOR, size))
                                    finish()
                                },
                                content = {
                                    Text(stringResource(R.string.generic_save))
                                },
                                modifier = Modifier.align(Alignment.End)
                            )
                        }
                    )
                }
            }
        }
    }
}