/*
 * Calculate Android Copyright <C> 2020 - 2025 Jonas Lochmann
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation version 3 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see https://www.gnu.org/licenses/
 */
package com.rechnen.app.ui.user

import androidx.compose.material3.AlertDialog
import androidx.compose.material3.Text
import androidx.compose.material3.TextButton
import androidx.compose.runtime.Composable
import androidx.compose.ui.res.stringResource
import com.rechnen.app.R
import com.rechnen.app.data.model.User

@Composable
fun DeleteUserDialog(user: User, listener: DeleteUserDialogListener) {
    AlertDialog(
        onDismissRequest = { listener.cancel() },
        text = { Text(stringResource(R.string.user_list_delete_user_question, user.name)) },
        confirmButton = { TextButton(
            content = { Text(stringResource(R.string.user_list_delete_user)) },
            onClick = { listener.confirm() }
        ) },
        dismissButton = {
            TextButton(
                content = { Text(stringResource(R.string.generic_cancel)) },
                onClick = { listener.cancel() }
            )
        }
    )
}

interface DeleteUserDialogListener {
    fun cancel()
    fun confirm()
}