/*
 * Calculate Android Copyright <C> 2020 - 2025 Jonas Lochmann
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation version 3 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see https://www.gnu.org/licenses/
 */
package com.rechnen.app.ui.user

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.ModalBottomSheet
import androidx.compose.material3.Text
import androidx.compose.material3.TextButton
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.stringResource
import com.rechnen.app.R
import com.rechnen.app.data.model.User

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun EditUserDialog(user: User, listener: EditUserListener) {
    @Composable
    fun MyButton(text: String, action: () -> Unit) {
        TextButton(
            onClick = action,
            content = { Text(text) },
            modifier = Modifier.fillMaxWidth()
        )
    }

    ModalBottomSheet(
        onDismissRequest = { listener.dismiss() },
        content = {
            Column {
                BottomSheet.Title(user.name)

                BottomSheet.ListItem(stringResource(R.string.time_trial_mode), null) { listener.startTimeTrial() }
                BottomSheet.ListItem(stringResource(R.string.user_list_view_statistic), null) { listener.viewStatistic() }
                BottomSheet.ListItem(stringResource(R.string.user_list_edit_difficulty), null) { listener.configureDifficulty() }
                BottomSheet.ListItem(stringResource(R.string.input_config_title), null) { listener.configureInput() }
                BottomSheet.ListItem(stringResource(R.string.user_list_delete_user), null) { listener.deleteUser() }
            }
        }
    )
}

interface EditUserListener {
    fun startTimeTrial()
    fun viewStatistic()
    fun configureDifficulty()
    fun configureInput()
    fun deleteUser()
    fun dismiss()
}