/*
 * Calculate Android Copyright <C> 2020 - 2025 Jonas Lochmann
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation version 3 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see https://www.gnu.org/licenses/
 */
package com.rechnen.app.ui.user

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.LinearProgressIndicator
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.ModalBottomSheet
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import com.rechnen.app.R
import com.rechnen.app.data.model.AggregatedStatisticTaskResult
import com.rechnen.app.data.model.User
import com.rechnen.app.ui.tasktype.TaskTypeInfo
import com.rechnen.app.ui.util.Time

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun ViewUserStatisticDialog(
    user: User,
    statistic: List<AggregatedStatisticTaskResult>,
    onDismissRequest: () -> Unit
) {
    ModalBottomSheet(
        onDismissRequest = onDismissRequest,
        content = {
            Column(Modifier.padding(16.dp)) {
                Text(
                    user.name,
                    style = MaterialTheme.typography.titleLarge,
                    textAlign = TextAlign.Center,
                    modifier = Modifier.fillMaxWidth()
                )

                if (user.playTime > 0)  {
                    Text(stringResource(
                        R.string.user_list_playtime,
                        Time.formatTime(user.playTime, LocalContext.current)
                    ))
                }

                Text(
                    LocalContext.current.resources.getQuantityString(
                        R.plurals.statistic_solved_tasks,
                        user.solvedTasks.toInt(),
                        user.solvedTasks.toInt()
                    )
                )

                if (statistic.isNotEmpty()) {
                    Text(
                        stringResource(R.string.statistic_recent_title),
                        style = MaterialTheme.typography.titleLarge,
                        textAlign = TextAlign.Center,
                        modifier = Modifier.fillMaxWidth()
                    )

                    for (item in statistic) {
                        Text(
                            stringResource(TaskTypeInfo.get(item.type).labelResourceId),
                            style = MaterialTheme.typography.titleMedium
                        )

                        Text(
                            stringResource(
                                R.string.statistic_solved_right_percent,
                                item.correct * 100 / item.total
                            )
                        )

                        LinearProgressIndicator(
                            progress = { item.correct.toFloat() / item.total.toFloat() },
                            modifier = Modifier.fillMaxWidth().padding(top = 4.dp, bottom = 8.dp)
                        )
                    }
                }
            }
        }
    )
}