/*
 * Calculate Android Copyright <C> 2020 - 2025 Jonas Lochmann
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation version 3 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see https://www.gnu.org/licenses/
 */
package com.rechnen.app.ui.view

import android.text.Spanned
import android.text.style.URLSpan
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.text.LinkAnnotation
import androidx.compose.ui.text.SpanStyle
import androidx.compose.ui.text.buildAnnotatedString
import androidx.compose.ui.text.style.TextDecoration

@Composable
fun HyperlinkText(text: CharSequence) {
    Text(buildAnnotatedString {
        append(text)

        if (text is Spanned) {
            text.getSpans(0, length, URLSpan::class.java).forEach { span ->
                span as URLSpan

                val start = text.getSpanStart(span)
                val end = text.getSpanEnd(span)

                addStyle(
                    SpanStyle(
                        textDecoration = TextDecoration.Underline
                    ),
                    start, end
                )

                addLink(
                    LinkAnnotation.Url(span.url),
                    start, end
                )
            }
        }
    })
}
